@@ -132,6 +132,7 @@
 (put 'nnir 'custom-loads '("nnir"))
 (put 'gnus-group-foreign 'custom-loads '("gnus-group" "gnus-msg"))
 (put 'gnus-offline 'custom-loads '("gnus-offline"))
+(put 'spam-ifile 'custom-loads '("spam"))
 (put 'mailcap 'custom-loads '("gnus-mailcap"))
 (put 'nnmail-prepare 'custom-loads '("nnmail"))
 (put 'gnus-article-signature 'custom-loads '("gnus-art"))
@@ -320,8 +321,9 @@ nil instead of to signal an error by setting the option
 
 ;;;### (autoloads (gnus-article-outlook-deuglify-article gnus-outlook-deuglify-article
 ;;;;;;  gnus-outlook-repair-attribution gnus-outlook-unwrap-lines
-;;;;;;  gnus-outlook-deuglify-unwrap-max gnus-outlook-deuglify-unwrap-min)
-;;;;;;  "deuglify" "deuglify.el" (15892 56060))
+;;;;;;  gnus-outlook-display-hook gnus-outlook-deuglify-unwrap-max
+;;;;;;  gnus-outlook-deuglify-unwrap-min) "deuglify" "deuglify.el"
+;;;;;;  (15905 9007))
 ;;; Generated autoloads from deuglify.el
 
 (defvar gnus-outlook-deuglify-unwrap-min 45 "\
@@ -330,18 +332,24 @@ Minimum length of the cited line above the (possibly) wrapped line.")
 (defvar gnus-outlook-deuglify-unwrap-max 95 "\
 Maximum length of the cited line after unwrapping.")
 
+(defvar gnus-outlook-display-hook nil "\
+A hook called after an deuglified article has been prepared.
+It is run after `gnus-article-prepare-hook'.")
+
 (autoload (quote gnus-outlook-unwrap-lines) "deuglify" "\
-Unwrap lines that appear to be wrapped citation lines.
+Unwrap lines that appear to be wrapped citation lines.  
 You can control what lines will be unwrapped by frobbing
-`gnus-outlook-deuglify-unwrap-min' and
-`gnus-outlook-deuglify-unwrap-max', indicating the miminum and maximum
-length of an unwrapped citation line." t nil)
+`gnus-outlook-deuglify-unwrap-min' and `gnus-outlook-deuglify-unwrap-max',
+indicating the miminum and maximum length of an unwrapped citation line.  If
+NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
 (autoload (quote gnus-outlook-repair-attribution) "deuglify" "\
-Repair a broken attribution line." t nil)
+Repair a broken attribution line.
+If NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
 (autoload (quote gnus-outlook-deuglify-article) "deuglify" "\
-Deuglify broken Outlook (Express) articles." t nil)
+Deuglify broken Outlook (Express) articles.
+If NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
 (autoload (quote gnus-article-outlook-deuglify-article) "deuglify" "\
 Deuglify broken Outlook (Express) articles and redisplay." t nil)
@@ -358,7 +366,7 @@ Play sounds in message buffers." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus gnus-other-frame gnus-slave gnus-no-server
-;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15892 56067))
+;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15903 44063))
 ;;; Generated autoloads from gnus.el
 
 (autoload (quote gnus-slave-no-server) "gnus" "\
@@ -397,7 +405,7 @@ prompt the user for the name of an NNTP server to use." t nil)
 ;;;### (autoloads (gnus-agent-regenerate gnus-agent-batch gnus-agent-batch-fetch
 ;;;;;;  gnus-agent-possibly-save-gcc gnus-agentize gnus-slave-unplugged
 ;;;;;;  gnus-plugged gnus-unplugged) "gnus-agent" "gnus-agent.el"
-;;;;;;  (15892 56060))
+;;;;;;  (15905 9007))
 ;;; Generated autoloads from gnus-agent.el
 
 (autoload (quote gnus-unplugged) "gnus-agent" "\
@@ -436,7 +444,7 @@ If CLEAN, don't read existing active files." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-article-prepare-display) "gnus-art" "gnus-art.el"
-;;;;;;  (15894 12366))
+;;;;;;  (15905 64763))
 ;;; Generated autoloads from gnus-art.el
 
 (autoload (quote gnus-article-prepare-display) "gnus-art" "\
@@ -597,8 +605,8 @@ Reminder user if there are unsent drafts." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-convert-gray-x-face-region gnus-convert-gray-x-face-to-xpm
-;;;;;;  gnus-x-face-from-file gnus-random-x-face) "gnus-fun" "gnus-fun.el"
-;;;;;;  (15622 36582))
+;;;;;;  gnus-convert-face-to-png gnus-face-from-file gnus-x-face-from-file
+;;;;;;  gnus-random-x-face) "gnus-fun" "gnus-fun.el" (15905 64772))
 ;;; Generated autoloads from gnus-fun.el
 
 (autoload (quote gnus-random-x-face) "gnus-fun" "\
@@ -607,6 +615,11 @@ Insert a random X-Face header from `gnus-x-face-directory'." t nil)
 (autoload (quote gnus-x-face-from-file) "gnus-fun" "\
 Insert an X-Face header based on an image file." t nil)
 
+(autoload (quote gnus-face-from-file) "gnus-fun" "\
+Return an Face header based on an image file." t nil)
+
+(autoload (quote gnus-convert-face-to-png) "gnus-fun" nil nil nil)
+
 (autoload (quote gnus-convert-gray-x-face-to-xpm) "gnus-fun" nil nil nil)
 
 (autoload (quote gnus-convert-gray-x-face-region) "gnus-fun" "\
@@ -615,7 +628,7 @@ Convert the X-Faces in region to a PPM file." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-fetch-group-other-frame gnus-fetch-group)
-;;;;;;  "gnus-group" "gnus-group.el" (15895 54922))
+;;;;;;  "gnus-group" "gnus-group.el" (15896 64964))
 ;;; Generated autoloads from gnus-group.el
 
 (autoload (quote gnus-fetch-group) "gnus-group" "\
@@ -761,7 +774,7 @@ Update the .newsrc.eld file to reflect the change of nntp server." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-button-reply gnus-button-mailto gnus-msg-mail)
-;;;;;;  "gnus-msg" "gnus-msg.el" (15892 56064))
+;;;;;;  "gnus-msg" "gnus-msg.el" (15905 64774))
 ;;; Generated autoloads from gnus-msg.el
 
 (autoload (quote gnus-msg-mail) "gnus-msg" "\
@@ -870,7 +883,7 @@ Add NUM into sorted LIST by side effect." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-sieve-article-add-rule gnus-sieve-generate
-;;;;;;  gnus-sieve-update) "gnus-sieve" "gnus-sieve.el" (15684 34916))
+;;;;;;  gnus-sieve-update) "gnus-sieve" "gnus-sieve.el" (15898 7136))
 ;;; Generated autoloads from gnus-sieve.el
 
 (autoload (quote gnus-sieve-update) "gnus-sieve" "\
@@ -909,7 +922,7 @@ Note -- this function hasn't been implemented yet." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-update-format) "gnus-spec" "gnus-spec.el"
-;;;;;;  (15792 7770))
+;;;;;;  (15900 44715))
 ;;; Generated autoloads from gnus-spec.el
 
 (autoload (quote gnus-update-format) "gnus-spec" "\
@@ -919,7 +932,7 @@ Update the format specification near point." t nil)
 
 ;;;### (autoloads (gnus-fixup-nnimap-unread-after-getting-new-news
 ;;;;;;  gnus-declare-backend gnus-unload) "gnus-start" "gnus-start.el"
-;;;;;;  (15892 12186))
+;;;;;;  (15905 9009))
 ;;; Generated autoloads from gnus-start.el
 
 (autoload (quote gnus-unload) "gnus-start" "\
@@ -968,8 +981,8 @@ Convert HTML to plain text in the current buffer." t nil)
 ;;;;;;  message-signature-separator message-from-style message-cross-post-note-function
 ;;;;;;  message-followup-to-note message-cross-post-note message-cross-post-default
 ;;;;;;  message-archive-note message-archive-header message-mark-insert-end
-;;;;;;  message-mark-insert-begin) "message" "message.el" (15892
-;;;;;;  56068))
+;;;;;;  message-mark-insert-begin) "message" "message.el" (15905
+;;;;;;  9012))
 ;;; Generated autoloads from message.el
 
 (defvar message-mark-insert-begin "--8<---------------cut here---------------start------------->8---\n" "\
@@ -987,9 +1000,9 @@ Note to insert why you wouldn't want this posting archived.
 If nil, don't insert any text in the body.")
 
 (defvar message-cross-post-default t "\
-When non-nil `message-cross-post-followup-to' will normally perform a
-crosspost.  If nil, `message-cross-post-followup-to' will only do a followup.
-Note that you can explicitly override this setting by calling
+When non-nil `message-cross-post-followup-to' will perform a crosspost.
+If nil, `message-cross-post-followup-to' will only do a followup.  Note that
+you can explicitly override this setting by calling
 `message-cross-post-followup-to' with a prefix.")
 
 (defvar message-cross-post-note "Crosspost & Followup-To: " "\
@@ -1002,7 +1015,7 @@ Note to insert before signature to notify of follow-up only.")
 Function to use to insert note about Crosspost or Followup-To.
 The function will be called with four arguments.  The function should not only
 insert a note, but also ensure old notes are deleted.  See the documentation
-for `message-cross-post-insert-note'. ")
+for `message-cross-post-insert-note'.")
 
 (defvar message-from-style (quote default) "\
 *Specifies how \"From\" headers look.
@@ -1085,14 +1098,14 @@ If nil, don't insert a signature.")
 (define-mail-user-agent (quote message-user-agent) (quote message-mail) (quote message-send-and-exit) (quote message-kill-buffer) (quote message-send-hook))
 
 (autoload (quote message-change-subject) "message" "\
-Ask for new Subject: header, append (was: <Old Subject>)." t nil)
+Ask for NEW-SUBJECT header, append (was: <Old Subject>)." t nil)
 
 (autoload (quote message-mark-inserted-region) "message" "\
 Mark some region in the current article with enclosing tags.
 See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)
 
 (autoload (quote message-mark-insert-file) "message" "\
-Inserts FILE at point, marking it with enclosing tags.
+Insert FILE at point, marking it with enclosing tags.
 See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)
 
 (autoload (quote message-add-archive-header) "message" "\
@@ -1114,7 +1127,7 @@ OLD-GROUPS.  OLD-GROUPS lists the old-groups the posting would have
 been made to before the user asked for a Crosspost." nil nil)
 
 (autoload (quote message-cross-post-followup-to) "message" "\
-Crossposts message and sets Followup-To to TARGET-GROUP.
+Crossposts message and set Followup-To to TARGET-GROUP.
 With prefix-argument just set Follow-Up, don't cross-post." t nil)
 
 (autoload (quote message-reduce-to-to-cc) "message" "\
@@ -1381,18 +1394,20 @@ This mode is an extended emacs-lisp mode.
 
 ;;;***
 
-;;;### (autoloads (sieve-upload sieve-manage) "sieve" "sieve.el"
-;;;;;;  (15684 34917))
+;;;### (autoloads (sieve-upload-and-bury sieve-upload sieve-manage)
+;;;;;;  "sieve" "sieve.el" (15905 64794))
 ;;; Generated autoloads from sieve.el
 
 (autoload (quote sieve-manage) "sieve" nil t nil)
 
 (autoload (quote sieve-upload) "sieve" nil t nil)
 
+(autoload (quote sieve-upload-and-bury) "sieve" nil t nil)
+
 ;;;***
 
-;;;### (autoloads (sieve-mode) "sieve-mode" "sieve-mode.el" (15594
-;;;;;;  51046))
+;;;### (autoloads (sieve-mode) "sieve-mode" "sieve-mode.el" (15905
+;;;;;;  64793))
 ;;; Generated autoloads from sieve-mode.el
 
 (autoload (quote sieve-mode) "sieve-mode" "\
